==> aristotle_metadata_registry-2.1.1-py3-none-any.whl: aristotle_mdr/forms/discussions.py <==
from django import forms
import aristotle_mdr.models as MDR
from aristotle_mdr.perms import user_can_view
from aristotle_mdr.contrib.autocomplete import widgets


class NewPostForm(forms.ModelForm):
    relatedItems = forms.ModelMultipleChoiceField(
        queryset=MDR._concept.objects.all(),
        label="Related items", required=False,
        widget=widgets.ConceptAutocompleteSelectMultiple()
    )

    class Meta:
        model = MDR.DiscussionPost
        fields = ['title', 'body', 'workgroup', 'relatedItems']

    def __init__(self, *args, **kwargs):
        self.user = kwargs.pop('user', None)
        super().__init__(*args, **kwargs)
        self.fields['workgroup'].queryset = self.user.profile.myWorkgroups

    def clean_relatedItems(self):
        """
        Attempting to add items you don't have permission to will silently fail.
        Its unlikely to happen in normal use.
        """
        relatedItems = self.cleaned_data['relatedItems']
        relatedItems = [i for i in relatedItems if user_can_view(self.user, i)]
        return relatedItems


class EditPostForm(forms.ModelForm):
    relatedItems = forms.ModelMultipleChoiceField(
        queryset=MDR._concept.objects.all(),
        label="Related items", required=False,
        widget=widgets.ConceptAutocompleteSelectMultiple()
    )

    class Meta:
        model = MDR.DiscussionPost
        exclude = ['author', 'workgroup', 'closed']


class CommentForm(forms.ModelForm):
    class Meta:
        model = MDR.DiscussionComment
        exclude = ['author', 'post']

==> aristotle_metadata_registry-3.0.2-py3-none-any.whl: aristotle_mdr/forms/discussions.py <==
from django import forms
import aristotle_mdr.models as MDR
from aristotle_mdr.perms import user_can_view
from aristotle_mdr.contrib.autocomplete import widgets
from aristotle_mdr.forms.utils import BootstrapableMixin


class NewPostForm(BootstrapableMixin, forms.ModelForm):
    relatedItems = forms.ModelMultipleChoiceField(
        queryset=MDR._concept.objects.all(),
        label="Related items", required=False,
        widget=widgets.ConceptAutocompleteSelectMultiple()
    )

    class Meta:
        model = MDR.DiscussionPost
        fields = ['title', 'body', 'workgroup', 'relatedItems']

    def __init__(self, *args, **kwargs):
        self.user = kwargs.pop('user', None)
        super().__init__(*args, **kwargs)
        self.fields['workgroup'].queryset = self.user.profile.myWorkgroups

    def clean_relatedItems(self):
        """
        Attempting to add items you don't have permission to will silently fail.
        Its unlikely to happen in normal use.
        """
        relatedItems = self.cleaned_data['relatedItems']
        relatedItems = [i for i in relatedItems if user_can_view(self.user, i)]
        return relatedItems


class EditPostForm(BootstrapableMixin, forms.ModelForm):
    relatedItems = forms.ModelMultipleChoiceField(
        queryset=MDR._concept.objects.all(),
        label="Related items", required=False,
        widget=widgets.ConceptAutocompleteSelectMultiple()
    )

    class Meta:
        model = MDR.DiscussionPost
        exclude = ['author', 'workgroup', 'closed']


class CommentForm(BootstrapableMixin, forms.ModelForm):
    class Meta:
        model = MDR.DiscussionComment
        exclude = ['author', 'post']
